==> haskell-ormolu-0.5.0.1-20-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-ormolu.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ormolu
version:              0.5.0.1
visibility:           public
id:                   ormolu-0.5.0.1-17i7JqrJ5rYI3vfKP9BmQ
key:                  ormolu-0.5.0.1-17i7JqrJ5rYI3vfKP9BmQ
license:              BSD-3-Clause
maintainer:           Mark Karpov <mark.karpov@tweag.io>
homepage:             https://github.com/tweag/ormolu
synopsis:             A formatter for Haskell source code
description:          A formatter for Haskell source code.
category:             Development, Formatting
abi:                  f3ecb2cc426f4c31820873e7927de49e
exposed:              True
exposed-modules:
    Ormolu Ormolu.Config Ormolu.Diff.ParseResult Ormolu.Diff.Text
    Ormolu.Exception Ormolu.Fixity Ormolu.Fixity.Internal
    Ormolu.Fixity.Parser Ormolu.Fixity.Printer Ormolu.Imports
    Ormolu.Parser Ormolu.Parser.CommentStream Ormolu.Parser.Pragma
    Ormolu.Parser.Result Ormolu.Printer Ormolu.Printer.Combinators
    Ormolu.Printer.Comments Ormolu.Printer.Internal
    Ormolu.Printer.Meat.Common Ormolu.Printer.Meat.Declaration
    Ormolu.Printer.Meat.Declaration.Annotation
    Ormolu.Printer.Meat.Declaration.Class
    Ormolu.Printer.Meat.Declaration.Data
    Ormolu.Printer.Meat.Declaration.Default
    Ormolu.Printer.Meat.Declaration.Foreign
    Ormolu.Printer.Meat.Declaration.Instance
    Ormolu.Printer.Meat.Declaration.OpTree
    Ormolu.Printer.Meat.Declaration.RoleAnnotation
    Ormolu.Printer.Meat.Declaration.Rule
    Ormolu.Printer.Meat.Declaration.Signature
    Ormolu.Printer.Meat.Declaration.Splice
    Ormolu.Printer.Meat.Declaration.Type
    Ormolu.Printer.Meat.Declaration.TypeFamily
    Ormolu.Printer.Meat.Declaration.Value
    Ormolu.Printer.Meat.Declaration.Warning
    Ormolu.Printer.Meat.ImportExport Ormolu.Printer.Meat.Module
    Ormolu.Printer.Meat.Pragma Ormolu.Printer.Meat.Type
    Ormolu.Printer.Operators Ormolu.Printer.SpanStream
    Ormolu.Processing.Common Ormolu.Processing.Cpp
    Ormolu.Processing.Preprocess Ormolu.Terminal Ormolu.Utils
    Ormolu.Utils.Cabal Ormolu.Utils.Fixity Ormolu.Utils.IO

hidden-modules:       GHC.DynFlags
import-dirs:          /usr/lib/ghc-9.2.8/site-local/ormolu-0.5.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/ormolu-0.5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ormolu
hs-libraries:         HSormolu-0.5.0.1-17i7JqrJ5rYI3vfKP9BmQ
depends:
    ghc-lib-parser-9.2.8.20230729-6yzmbZWPLh1ApSJzIn9d5 Cabal-3.6.3.0
    Diff-0.4.1-GFCkXoW1sOmEQbYHDvlnNI
    MemoTrie-0.6.10-83ph265d8GcLx6I2AIzUEy
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr
    ansi-terminal-0.11.5-FgXvUwo3mIX2g72exyhUhE array-0.5.4.0
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1
    directory-1.3.6.2 dlist-1.0-LNr75TD4CZoKEEzkBmhWjA
    exceptions-0.10.4 filepath-1.4.2.2
    megaparsec-9.6.0-6jYDQ0q8YWM1z9BbCkR7uD mtl-2.2.2
    syb-0.7.2.4-4iiIjHgm67gJA1HTgFmr8s template-haskell-2.18.0.0
    text-1.2.5.0 th-lift-instances-0.1.20-7UUlrTsIDWL3XQkjxcQngm

haddock-interfaces:   /usr/share/doc/haskell-ormolu/html/ormolu.haddock
haddock-html:         /usr/share/doc/haskell-ormolu/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ormolu-0.5.1.0-28.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-ormolu.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ormolu
version:              0.5.1.0
visibility:           public
id:                   ormolu-0.5.1.0-CTad0Ykn2gm5rdL7uPHDhB
key:                  ormolu-0.5.1.0-CTad0Ykn2gm5rdL7uPHDhB
license:              BSD-3-Clause
maintainer:           Mark Karpov <mark.karpov@tweag.io>
homepage:             https://github.com/tweag/ormolu
synopsis:             A formatter for Haskell source code
description:          A formatter for Haskell source code.
category:             Development, Formatting
abi:                  230bab356329af71d9aad329e46042f2
exposed:              True
exposed-modules:
    Ormolu Ormolu.Config Ormolu.Diff.ParseResult Ormolu.Diff.Text
    Ormolu.Exception Ormolu.Fixity Ormolu.Fixity.Internal
    Ormolu.Fixity.Parser Ormolu.Fixity.Printer Ormolu.Imports
    Ormolu.Parser Ormolu.Parser.CommentStream Ormolu.Parser.Pragma
    Ormolu.Parser.Result Ormolu.Printer Ormolu.Printer.Combinators
    Ormolu.Printer.Comments Ormolu.Printer.Internal
    Ormolu.Printer.Meat.Common Ormolu.Printer.Meat.Declaration
    Ormolu.Printer.Meat.Declaration.Annotation
    Ormolu.Printer.Meat.Declaration.Class
    Ormolu.Printer.Meat.Declaration.Data
    Ormolu.Printer.Meat.Declaration.Default
    Ormolu.Printer.Meat.Declaration.Foreign
    Ormolu.Printer.Meat.Declaration.Instance
    Ormolu.Printer.Meat.Declaration.OpTree
    Ormolu.Printer.Meat.Declaration.RoleAnnotation
    Ormolu.Printer.Meat.Declaration.Rule
    Ormolu.Printer.Meat.Declaration.Signature
    Ormolu.Printer.Meat.Declaration.Splice
    Ormolu.Printer.Meat.Declaration.Type
    Ormolu.Printer.Meat.Declaration.TypeFamily
    Ormolu.Printer.Meat.Declaration.Value
    Ormolu.Printer.Meat.Declaration.Warning
    Ormolu.Printer.Meat.ImportExport Ormolu.Printer.Meat.Module
    Ormolu.Printer.Meat.Pragma Ormolu.Printer.Meat.Type
    Ormolu.Printer.Operators Ormolu.Printer.SpanStream
    Ormolu.Processing.Common Ormolu.Processing.Cpp
    Ormolu.Processing.Preprocess Ormolu.Terminal Ormolu.Utils
    Ormolu.Utils.Cabal Ormolu.Utils.Fixity Ormolu.Utils.IO

hidden-modules:       GHC.DynFlags
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ormolu-0.5.1.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ormolu-0.5.1.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ormolu-0.5.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ormolu
hs-libraries:         HSormolu-0.5.1.0-CTad0Ykn2gm5rdL7uPHDhB
depends:
    ghc-lib-parser-9.4.8.20231111-CMOJ2xE30mV7zGHnMbamXO
    Cabal-syntax-3.8.1.0 Diff-0.4.1-Jc1TR9aaNUv129X0zlHNSG
    MemoTrie-0.6.11-CZlZiu1VJ6jByImjJrWSzb
    aeson-2.1.2.1-38LADbNStwmEfKOReucTQy
    ansi-terminal-1.0.2-CHKNXEXhuZ3EvZtvAUncPO array-0.5.4.0
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    directory-1.3.7.1 dlist-1.0-I6FB5Nlk17hG16fxQzZSEb
    exceptions-0.10.5 filepath-1.4.2.2
    megaparsec-9.6.1-6pqHq8BNT2333chbXCRu9H mtl-2.2.2
    syb-0.7.2.4-2YD6CDfMmJX8WUaza11ezv template-haskell-2.19.0.0
    text-2.0.2 th-lift-instances-0.1.20-1D614bxnfwAIHCJVjbInhO

haddock-interfaces:   /usr/share/doc/haskell-ormolu/html/ormolu.haddock
haddock-html:         /usr/share/doc/haskell-ormolu/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
